==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstopvragen/v20130701/BestandenlijstOpvragenRequest.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragen.v20130701.BestandenlijstOpvragenType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="verzoek" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragen/v20130701}BestandenlijstOpvragenType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "verzoek"
})
@XmlRootElement(name = "BestandenlijstOpvragenRequest")
public class BestandenlijstOpvragenRequest {

    @XmlElement(required = true)
    protected BestandenlijstOpvragenType verzoek;

    /**
     * Gets the value of the verzoek property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenlijstOpvragenType }
     *     
     */
    public BestandenlijstOpvragenType getVerzoek() {
        return verzoek;
    }

    /**
     * Sets the value of the verzoek property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenlijstOpvragenType }
     *     
     */
    public void setVerzoek(BestandenlijstOpvragenType value) {
        this.verzoek = value;
    }

}

==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstopvragen/v20130701/BestandenlijstOpvragenRequest.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragen.v20130701.BestandenlijstOpvragenType;


/**
 * &lt;p&gt;Java class for anonymous complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="verzoek" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragen/v20130701}BestandenlijstOpvragenType"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "verzoek"
})
@XmlRootElement(name = "BestandenlijstOpvragenRequest")
public class BestandenlijstOpvragenRequest {

    @XmlElement(required = true)
    protected BestandenlijstOpvragenType verzoek;

    /**
     * Gets the value of the verzoek property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenlijstOpvragenType }
     *     
     */
    public BestandenlijstOpvragenType getVerzoek() {
        return verzoek;
    }

    /**
     * Sets the value of the verzoek property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenlijstOpvragenType }
     *     
     */
    public void setVerzoek(BestandenlijstOpvragenType value) {
        this.verzoek = value;
    }

}
